@@ -8,4 +8,6 @@ class PageNode(FileNode):
     @property
     @check_config_first
     def is_page(self):
+        if self.config.get('is_asset') is not None:
+            return not self.is_asset
         return True
